from django.conf import settings
from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('cmsplugin_cascade', '0027_version_1'),
    ]

    operations = [
        migrations.AddField(
            model_name='cascadeclipboard',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now, verbose_name='Created at'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='cascadeclipboard',
            name='created_by',
            field=models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='Created by'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='cascadeclipboard',
            name='last_accessed_at',
            field=models.DateTimeField(default=None, editable=False, null=True, verbose_name='Last accessed at'),
        ),
    ]



"""
See PEP 386 (https://www.python.org/dev/peps/pep-0386/)

Release logic:
 1. Remove ".devX" from __version__ (below)
 2. Remove ".devX" latest version in docs/source/changelog.rst
 3. git add cmsplugin_cascade/__init__.py docs/source/changelog.rst
 4. git commit -m 'Bump to <version>'
 5. git tag <version>
 6. git push
 7. assure that all tests pass on https://github.com/jrief/django-formset/actions/workflows/tests.yml
 8. git push --tags
 9. assure that a new version is published on https://github.com/jrief/django-formset/actions/workflows/publish.yml
10. bump the version, append ".dev0" to __version__
11. Add a new heading to docs/source/changelog.rst, named "<next-version>.dev0"
12. git add cmsplugin_cascade/__init__.py docs/source/changelog.rst
13. git commit -m 'Start with <version>'
14. git push
"""
__version__ = "2.3.3"

default_app_config = 'cmsplugin_cascade.apps.CascadeConfig'



from django.db import migrations, models
import django.db.models.deletion
import filer.fields.file
import cmsplugin_cascade.models


class Migration(migrations.Migration):

    dependencies = [
        ('filer', '0006_auto_20160623_1627'),
        ('cmsplugin_cascade', '0012_auto_20160619_1854'),
    ]

    operations = [
        migrations.CreateModel(
            name='IconFont',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('identifier', models.CharField(help_text='A unique identifier to distinguish this icon font.', max_length=50, unique=True, verbose_name='Identifier')),
                ('config_data', models.JSONField()),
                ('font_folder', cmsplugin_cascade.models.FilePathField(allow_files=False, allow_folders=True)),
                ('zip_file', filer.fields.file.FilerFileField(help_text='Upload a zip file created on <a href="http://fontello.com/" target="_blank">Fontello</a> containing fonts.', on_delete=django.db.models.deletion.CASCADE, to='filer.File')),
            ],
            options={
                'verbose_name': 'Uploaded Icon Font',
                'verbose_name_plural': 'Uploaded Icon Fonts',
            },
        ),
    ]
